authz

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2024 License: MIT Imports: 5 Imported by: 0

README

Authz

CodeQL Run Tests codecov Go Report Card GoDoc

Authz is an authorization middleware for Gin, it's based on https://github.com/casbin/casbin.

Installation

go get github.com/gin-contrib/authz

Simple Example

package main

import (
  "net/http"

  "github.com/casbin/casbin/v2"
  "github.com/gin-contrib/authz"
  "github.com/gin-gonic/gin"
)

func main() {
  // load the casbin model and policy from files, database is also supported.
  e := casbin.NewEnforcer("authz_model.conf", "authz_policy.csv")

  // define your router, and use the Casbin authz middleware.
  // the access that is denied by authz will return HTTP 403 error.
  router := gin.New()
  router.Use(authz.NewAuthorizer(e))
}

Documentation

The authorization determines a request based on {subject, object, action}, which means what subject can perform what action on what object. In this plugin, the meanings are:

  1. subject: the logged-on user name
  2. object: the URL path for the web resource like "dataset1/item1"
  3. action: HTTP method like GET, POST, PUT, DELETE, or the high-level actions you defined like "read-file", "write-blog"

For how to write authorization policy and other details, please refer to the Casbin's documentation.

Getting Help

License

This project is under MIT License. See the LICENSE file for the full license text.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCustomAuthorizer

func NewCustomAuthorizer(e *casbin.Enforcer) gin.HandlerFunc

NewCustomAuthorizer returns a custom authorizer that uses a Casbin enforcer as input.

Types

type CustomAuthorizer

type CustomAuthorizer struct {
	// contains filtered or unexported fields
}

CustomAuthorizer is a custom authorizer that checks roles in the Gin context for permissions.

func (*CustomAuthorizer) CheckPermission

func (a *CustomAuthorizer) CheckPermission(c *gin.Context) bool

CheckPermission checks if the roles in the Gin context have permission for the requested URL and HTTP verb.

func (*CustomAuthorizer) RequirePermission

func (a *CustomAuthorizer) RequirePermission(c *gin.Context)

RequirePermission returns the 403 Forbidden status to the client

Jump to